@@ -9,7 +9,7 @@ Created on Wed Jan 12 18:29:30 2022
 from BDMLtools.selector.bin import binSelector,binAdjuster
 from BDMLtools.selector.bin_fun import binFreq,binPretty,binTree,binChi2,binKmeans
 from BDMLtools.selector.fa import faSelector
-from BDMLtools.selector.embeded import lassoSelector
+from BDMLtools.selector.embeded import LassoLogit
 from BDMLtools.selector.logtit import stepLogit,cardScorer
 from BDMLtools.selector.simple import prefitModel,preSelector
 from BDMLtools.selector.lgbm import LgbmPISelector,LgbmShapRFECVSelector,LgbmSeqSelector
@@ -28,7 +28,7 @@ __all__ = (
     LgbmShapRFECVSelector,
     LgbmSeqSelector,
     faSelector,
-    lassoSelector,
+    LassoLogit,
     stepLogit,
     cardScorer,
     prefitModel,
